@@ -66,9 +66,9 @@ public class TitleRegion extends Canvas {
 	private Image image;
 	private BusyIndicator busyLabel;
 	private Control currentTitleControl;
-	private Label titleLabel;
-	private StyledText titleText;
-	private SizeCache titleCache;
+	private final Label titleLabel;
+	private final StyledText titleText;
+	private final SizeCache titleCache;
 	private int fontHeight = -1;
 	private int fontBaselineHeight = -1;
 	private MenuHyperlink menuHyperlink;
@@ -98,10 +98,11 @@ public class TitleRegion extends Canvas {
 
 		@Override
 		public void mouseMove(MouseEvent e) {
-			if (e.button > 0)
+			if (e.button > 0) {
 				setHoverState(STATE_NORMAL);
-			else
+			} else {
 				setHoverState(STATE_HOVER_FULL);
+			}
 		}
 	}
 
@@ -154,17 +155,21 @@ public class TitleRegion extends Canvas {
 			if (menuManager != null) {
 				menuHyperlink.setVisible(!menuManager.isEmpty()
 						&& currentTitleControl.getVisible());
-				if (menuHyperlink.getVisible())
+				if (menuHyperlink.getVisible()) {
 					msize = menuHyperlink.computeSize(SWT.DEFAULT, SWT.DEFAULT);
+				}
 			}
-			if (flushCache)
+			if (flushCache) {
 				titleCache.flush();
+			}
 			titleCache.setControl(currentTitleControl);
 			int twidth = iwidth == SWT.DEFAULT ? iwidth : iwidth - SPACING * 2;
-			if (bsize != null && twidth != SWT.DEFAULT)
+			if (bsize != null && twidth != SWT.DEFAULT) {
 				twidth -= bsize.x + SPACING;
-			if (msize != null && twidth != SWT.DEFAULT)
+			}
+			if (msize != null && twidth != SWT.DEFAULT) {
 				twidth -= msize.x + SPACING;
+			}
 			if (currentTitleControl.getVisible()) {
 				tsize = titleCache.computeSize(twidth, SWT.DEFAULT);
 				if (twidth != SWT.DEFAULT) {
@@ -177,8 +182,9 @@ public class TitleRegion extends Canvas {
 					// System.out.println("twidth="+twidth+",
 					// tsize.x="+tsize.x); //$NON-NLS-1$//$NON-NLS-2$
 				}
-			} else
+			} else {
 				tsize = new Point(0, 0);
+			}
 			Point size = new Point(width, height);
 			if (!move) {
 				// compute size
@@ -192,10 +198,11 @@ public class TitleRegion extends Canvas {
 					size.x += msize.x + SPACING;
 					size.y = Math.max(size.y, msize.y);
 				}
-				if (size.y > 0)
+				if (size.y > 0) {
 					size.y += VMARGIN * 2;
 				// System.out.println("Compute size: width="+width+",
 				// size.x="+size.x); //$NON-NLS-1$ //$NON-NLS-2$
+				}
 			} else {
 				// position controls
 				int xloc = x + HMARGIN + SPACING;
@@ -216,10 +223,12 @@ public class TitleRegion extends Canvas {
 					else if (Constants.OS_FREEBSD.equalsIgnoreCase(os)) {
 						tw += 1; // See Bug 342610
 					}
-					if (bsize != null)
+					if (bsize != null) {
 						tw -= bsize.x + SPACING;
-					if (msize != null)
+					}
+					if (msize != null) {
 						tw -= msize.x + SPACING;
+					}
 					currentTitleControl.setBounds(xloc,
 					// yloc + height / 2 - tsize.y / 2,
 							yloc, tw, tsize.y);
@@ -280,8 +289,9 @@ public class TitleRegion extends Canvas {
 	}
 
 	private void onPaint(PaintEvent e) {
-		if (hoverState == STATE_NORMAL)
+		if (hoverState == STATE_NORMAL) {
 			return;
+		}
 		GC gc = e.gc;
 		Rectangle carea = getClientArea();
 		gc.setBackground(getHoverBackground());
@@ -293,33 +303,38 @@ public class TitleRegion extends Canvas {
 	}
 
 	private Color getHoverBackground() {
-		if (hoverState == STATE_NORMAL)
+		if (hoverState == STATE_NORMAL) {
 			return null;
+		}
 		Color color = getColor(hoverState == STATE_HOVER_FULL ? IFormColors.H_HOVER_FULL
 				: IFormColors.H_HOVER_LIGHT);
-		if (color == null)
+		if (color == null) {
 			color = getDisplay()
 					.getSystemColor(
 							hoverState == STATE_HOVER_FULL ? SWT.COLOR_WIDGET_BACKGROUND
 									: SWT.COLOR_WIDGET_LIGHT_SHADOW);
+		}
 		return color;
 	}
 
 	public void setHoverState(int state) {
-		if (dragSource == null || this.hoverState == state)
+		if (dragSource == null || this.hoverState == state) {
 			return;
+		}
 		this.hoverState = state;
 		Color color = getHoverBackground();
 		titleLabel.setBackground(color != null ? color
 				: getColor(FormHeading.COLOR_BASE_BG));
 		titleText.setBackground(color != null ? color
 				: getColor(FormHeading.COLOR_BASE_BG));
-		if (busyLabel != null)
+		if (busyLabel != null) {
 			busyLabel.setBackground(color != null ? color
 					: getColor(FormHeading.COLOR_BASE_BG));
-		if (menuHyperlink != null)
+		}
+		if (menuHyperlink != null) {
 			menuHyperlink.setBackground(color != null ? color
 					: getColor(FormHeading.COLOR_BASE_BG));
+		}
 		redraw();
 	}
 
@@ -359,13 +374,15 @@ public class TitleRegion extends Canvas {
 		if (busyLabel != null) {
 			busyLabel.setImage(theImage);
 		}
-		if (doLayout)
+		if (doLayout) {
 			layout();
+		}
 	}
 
 	public void updateToolTip(String toolTip) {
-		if (busyLabel != null)
+		if (busyLabel != null) {
 			busyLabel.setToolTipText(toolTip);
+		}
 	}
 
 	@Override
@@ -373,10 +390,12 @@ public class TitleRegion extends Canvas {
 		super.setBackground(bg);
 		titleLabel.setBackground(bg);
 		titleText.setBackground(bg);
-		if (busyLabel != null)
+		if (busyLabel != null) {
 			busyLabel.setBackground(bg);
-		if (menuHyperlink != null)
+		}
+		if (menuHyperlink != null) {
 			menuHyperlink.setBackground(bg);
+		}
 	}
 
 	@Override
@@ -384,8 +403,9 @@ public class TitleRegion extends Canvas {
 		super.setForeground(fg);
 		titleLabel.setForeground(fg);
 		titleText.setForeground(fg);
-		if (menuHyperlink != null)
+		if (menuHyperlink != null) {
 			menuHyperlink.setForeground(fg);
+		}
 	}
 
 	public void setText(String text) {
@@ -442,14 +462,17 @@ public class TitleRegion extends Canvas {
 			HoverListener listener = new HoverListener();
 			busyLabel.addMouseTrackListener(listener);
 			busyLabel.addMouseMoveListener(listener);
-			if (menuManager != null)
+			if (menuManager != null) {
 				busyLabel.setMenu(menuManager.createContextMenu(this));
-			if (dragSupport)
+			}
+			if (dragSupport) {
 				addDragSupport(busyLabel, dragOperations, dragTransferTypes, dragListener);
+			}
 			IMessageToolTipManager mng = ((FormHeading) getParent())
 					.getMessageToolTipManager();
-			if (mng != null)
+			if (mng != null) {
 				mng.createToolTip(busyLabel, true);
+			}
 		}
 	}
 
@@ -461,8 +484,9 @@ public class TitleRegion extends Canvas {
 		HoverListener listener = new HoverListener();
 		menuHyperlink.addMouseTrackListener(listener);
 		menuHyperlink.addMouseMoveListener(listener);
-		if (dragSupport)
+		if (dragSupport) {
 			addDragSupport(menuHyperlink, dragOperations, dragTransferTypes, dragListener);
+		}
 	}
 
 	/**
@@ -473,12 +497,14 @@ public class TitleRegion extends Canvas {
 	 *            the form's busy state
 	 */
 	public boolean setBusy(boolean busy) {
-		if (busy)
+		if (busy) {
 			ensureBusyLabelExists();
-		else if (busyLabel == null)
+		} else if (busyLabel == null) {
 			return false;
-		if (busy == busyLabel.isBusy())
+		}
+		if (busy == busyLabel.isBusy()) {
 			return false;
+		}
 		busyLabel.setBusy(busy);
 		if (busyLabel.getImage() == null) {
 			layout();
@@ -529,8 +555,9 @@ public class TitleRegion extends Canvas {
 			setMenu(menu);
 			titleLabel.setMenu(menu);
 			titleText.setMenu(menu);
-			if (busyLabel != null)
+			if (busyLabel != null) {
 				busyLabel.setMenu(menu);
+			}
 			createMenuHyperlink();
 		}
 		return menuManager;
@@ -545,10 +572,12 @@ public class TitleRegion extends Canvas {
 		dragSource = addDragSupport(titleLabel, operations, transferTypes,
 				listener);
 		addDragSupport(this, operations, transferTypes, listener);
-		if (busyLabel != null)
+		if (busyLabel != null) {
 			addDragSupport(busyLabel, operations, transferTypes, listener);
-		if (menuHyperlink != null)
+		}
+		if (menuHyperlink != null) {
 			addDragSupport(menuHyperlink, operations, transferTypes, listener);
+		}
 	}
 
 	private DragSource addDragSupport(Control control, int operations,
