@@ -13,15 +13,14 @@
  *******************************************************************************/
 package org.eclipse.jface.tests.performance;
 
-import org.junit.runner.RunWith;
-import org.junit.runners.Suite;
-import org.junit.runners.Suite.SuiteClasses;
+import org.junit.platform.suite.api.Suite;
+import org.junit.platform.suite.api.SelectClasses;
 
 /**
  * The JFacePerformanceSuite are the performance tests for JFace.
  */
-@RunWith(Suite.class)
-@SuiteClasses({ //
+@Suite
+@SelectClasses({ //
 		ListViewerRefreshTest.class, //
 		ComboViewerRefreshTest.class, //
 		FastTableViewerRefreshTest.class, //
